analphipy.Phi\_nm
=================

.. currentmodule:: analphipy

.. autoclass:: Phi_nm

   
   ..
      .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree:
   
      ~Phi_nm.__init__
      ~Phi_nm.asdict
      ~Phi_nm.assign
      ~Phi_nm.assign_min_numeric
      ~Phi_nm.cut
      ~Phi_nm.dphidr
      ~Phi_nm.lfs
      ~Phi_nm.minimize
      ~Phi_nm.new_like
      ~Phi_nm.phi
      ~Phi_nm.to_measures
      ~Phi_nm.to_nf
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
      :toctree:
   
      ~Phi_nm.n
      ~Phi_nm.m
      ~Phi_nm.sig
      ~Phi_nm.eps
      ~Phi_nm.phi_min
      ~Phi_nm.r_min
      ~Phi_nm.segments
   
   

   
   
   .. rubric:: Dunder Methods

   .. autosummary::
      :toctree:
   
      ~Phi_nm.__repr__
   
   